@@ -1,7 +1,7 @@
 /* **********************************************************
  * Copyright (C) 1998-2000 VMware, Inc.
  * All Rights Reserved
- * $Id: x86.h,v 1.9 2003/06/30 17:53:08 jdolecek Exp $
+ * $Id: x86.h,v 1.10 2004/12/07 21:05:19 jdolecek Exp $
  * **********************************************************/
 
 #ifndef _X86_H_
@@ -9,7 +9,7 @@
 
 #ifdef __NetBSD__
 #include <sys/param.h>		/* for __NetBSD_Version__ */
-#include <i386/specialreg.h>	/* for MSR_* */
+#include <machine/specialreg.h>	/* for MSR_* */
 
 # if __NetBSD_Version__ > 105009900
 #  include <uvm/uvm_extern.h>
