@@ -124,7 +124,7 @@ static int LinuxDriverAPMstate = APM_STATE_READY;
 #ifdef VMX86_DEVEL
 #define TAGNAME "(development)"
 #else
-#define TAGNAME "$Name: HEAD $"
+#define TAGNAME "$Name:  $"
 #endif
 
 struct VMXLinuxState linuxState;
