@@ -80,7 +80,7 @@
 #endif
 
 /* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ == 106220000
+#if __NetBSD_Version__ == 106220000 || __NetBSD_Version__ >= 399001400
 #define ENTRYARG	lwp
 #define LWP2PROC(l)	(l->l_proc)
 #else
@@ -426,7 +426,11 @@ vmmon_alloc_low_pages(struct vmx86_softc *vmxsc, unsigned long numPages, PA *add
 	/*
 	 * Map the segment into wired kernel virtual memory.
 	 */
+#if __NetBSD_Version__ >= 399000300
+	va = uvm_km_alloc(kernel_map, numPages * PAGE_SIZE, 0, UVM_KMF_VAONLY);
+#else
 	va = uvm_km_valloc(kernel_map, numPages * PAGE_SIZE);
+#endif
 	if (va == 0) {
 		VMDEBUG("vmmon_alloc_low_pages: km_valloc failed\n");
 		goto bad;
@@ -496,7 +500,15 @@ vmmon_destroy_low_pages(MemRange *r)
 	/*
 	 * Unmap the kernel virtual memory used by this range.
 	 */
+#if __NetBSD_Version__ >= 399000300
+	pmap_remove(pmap_kernel(), (vaddr_t)r->kAddr,
+	    (vaddr_t)r->kAddr + r->numPages * PAGE_SIZE);
+	pmap_update(pmap_kernel());
+	uvm_km_free(kernel_map, (vaddr_t)r->kAddr, r->numPages * PAGE_SIZE,
+	    UVM_KMF_VAONLY);
+#else
 	uvm_km_free(kernel_map, (vaddr_t)r->kAddr, r->numPages * PAGE_SIZE);
+#endif
 
 	/*
 	 * Build a list of pages to free back to the VM system.
