@@ -656,7 +656,12 @@ HostIF_UserToDriverPtr(VMDriver *vm, // IN
 	    VM_PROT_READ|VM_PROT_WRITE|VM_PROT_EXECUTE);
 
 	uaddr = (vaddr_t)addr;
+#if __NetBSD_Version__ >= 399000300
+	kvaddr = uvm_km_alloc(kernel_map, PAGE_SIZE, 0,
+	    UVM_KMF_VAONLY | UVM_KMF_WAITVA);
+#else
 	kvaddr = uvm_km_valloc_wait(kernel_map, PAGE_SIZE);
+#endif
 	pmap_extract(vm_map_pmap(&curproc->p_vmspace->vm_map), uaddr, &paddr);
 	pmap_kenter_pa(kvaddr, paddr,
 	    VM_PROT_READ | VM_PROT_WRITE | VM_PROT_EXECUTE);
