@@ -101,7 +101,7 @@ static int ether_ioctl(struct ifnet *, u_long, caddr_t);
 #endif
 
 /* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ == 106220000
+#if __NetBSD_Version__ == 106220000 || __NetBSD_Version__ >= 399001400
 #define ENTRYARG	lwp
 #define LWP2PROC(l)	(l->l_proc)
 #else
@@ -433,7 +433,12 @@ port_mappoll(struct hubport_softc *portsc, vaddr_t uaddr)
 	off = uaddr - upage;
 	if (off > (PAGE_SIZE - sizeof(u_int32_t)))
 		return EINVAL;
+#if __NetBSD_Version__ >= 399000300
+	kpage = uvm_km_alloc(kernel_map, PAGE_SIZE, 0,
+	    UVM_KMF_VAONLY | UVM_KMF_WAITVA);
+#else
 	kpage = uvm_km_valloc_wait(kernel_map, PAGE_SIZE);
+#endif
 	kaddr = kpage + off;
 
 	PHOLD(CURLWP);
@@ -456,7 +461,11 @@ port_mappoll(struct hubport_softc *portsc, vaddr_t uaddr)
 
     err:
 	PRELE(CURLWP);
+#if __NetBSD_Version__ >= 399000300
+	uvm_km_free(kernel_map, kpage, PAGE_SIZE, UVM_KMF_VAONLY);
+#else
 	uvm_km_free_wakeup(kernel_map, kpage, PAGE_SIZE);
+#endif
 	return (error);
 }
 
@@ -467,7 +476,12 @@ port_unmappoll(struct hubport_softc *portsc)
 #if 1
 	pmap_update(pmap_kernel());
 #endif
+#if __NetBSD_Version__ >= 399000300
+	uvm_km_free(kernel_map, portsc->port_kpollpage, PAGE_SIZE,
+	    UVM_KMF_VAONLY);
+#else
 	uvm_km_free_wakeup(kernel_map, portsc->port_kpollpage, PAGE_SIZE);
+#endif
 	PHOLD(CURLWP);
 	uvm_vsunlock(curproc, (void *)portsc->port_upollpage, PAGE_SIZE);
 	PRELE(CURLWP);
